import logging
from termcolor import colored

def _set_log():
    logger = logging.getLogger('xjm_log')
    logger.setLevel(logging.DEBUG)

    ch_hander = logging.StreamHandler()
    fh_hander = logging.FileHandler('/home/wangyn/xjm/PFnet/xjm_logging_log')

    ch_hander.setLevel(logging.DEBUG)
    fh_hander.setLevel(logging.DEBUG)

    # fmt = '%(asctime)s %(name)s %filename)s %(lineno)d: %(levelname)s %(message)s'
    fmt = logging.Formatter("%(asctime)s - %(name)s  - line:%(lineno)d - %(levelname)s - %(message)s")
    color_fmt = colored('%(asctime)s %(name)s', 'green') + colored(' %(filename)s %(lineno)d', 'yellow') + ':%(levelname)s %(message)s'  #%filename)s
    ch_hander.setFormatter((logging.Formatter(fmt=color_fmt, datefmt='%Y-%m-%d %H:%M:%S')))
    # fh_hander.setFormatter(logging.Formatter(fmt=fmt, datefmt='%Y-%m-%d %H:%M:%S'))
    # ch_hander.setFormatter(fmt)
    fh_hander.setFormatter(fmt)


    logger.addHandler(ch_hander)
    logger.addHandler(fh_hander)

    return logger


import os

from PIL import Image

image_root_path = '/home/xjm/xjm/xjm_pycharm/swin_transformer/datasets/3_data/train/2/'
mask_root_path = '/home/data/zgdata/mask_img/mask/'

image_save_path = '/home/xjm/xjm/xjm_pycharm/swin_transformer/datasets/3_data/train_aug/2/'
mask_save_path = '/home/data/zgdata/mask_img/aug_data/mask/'

i = 0
for img_name in os.listdir(image_root_path):
    # mask_name = img_name.replace('jpg', 'png')

    if img_name != 'Thumbs.db':

        img = Image.open(os.path.join(image_root_path,img_name))
        # mask = Image.open(os.path.join(mask_root_path,mask_name))

        img.save(image_save_path + 'original_' + img_name)
        # mask.save(mask_save_path + 'original_' + f'{i:012d}.png')


        '''
        上下翻转
        '''
        img_flip_TB = img.transpose(Image.FLIP_TOP_BOTTOM)
        # mask_flip_TB = mask.transpose(Image.FLIP_TOP_BOTTOM)

        img_flip_TB.save(image_save_path + 'FLIP_T_B_' + img_name)
        # img_flip_TB.save(mask_save_path + 'FLIP_T_B_' + f'{i:012d}.png')

        '''
        左右翻转
        '''
        img_flip_lr = img.transpose(Image.FLIP_LEFT_RIGHT)
        # mask_flip_lr = mask.transpose(Image.FLIP_LEFT_RIGHT)

        img_flip_lr.save(image_save_path + 'FLIP_L_R_' + img_name)
        # mask_flip_lr.save(mask_save_path + 'FLIP_L_R_' + f'{i:012d}.png')

        '''
        旋转30度
        '''
        img_rotate_30 = img.rotate(30)
        # mask_rotate_30 = mask.rotate(30)

        img_rotate_30.save(image_save_path + 'Rotate_30_' + img_name)
        # mask_rotate_30.save(mask_save_path + 'Rotate_30_' + f'{i:012d}.png')

        '''
        旋转60度
        '''
        img_rotate_60 = img.rotate(60)
        # mask_rotate_60 = mask.rotate(60)

        img_rotate_60.save(image_save_path + 'Rotate_60_' + img_name)
        # mask_rotate_60.save(mask_save_path + 'Rotate_60_' + f'{i:012d}.png')

        '''
        旋转120度
        '''
        img_rotate_120 = img.rotate(120)
        # mask_rotate_120 = mask.rotate(120)

        img_rotate_120.save(image_save_path + 'Rotate_120_' + img_name)
        # mask_rotate_120.save(mask_save_path + 'Rotate_120_' + f'{i:012d}.png')

        '''
        旋转150度
        '''
        img_rotate_150 = img.rotate(150)
        # mask_rotate_150 = mask.rotate(150)

        img_rotate_150.save(image_save_path + 'Rotate_150_' + img_name)
        # mask_rotate_150.save(mask_save_path + 'Rotate_150_' + f'{i:012d}.png')

        i += 1


import os
import torch
import torch.nn as nn

import torchvision
from torchvision import models

class Model_Process():
    def __init__(self, args) -> None:
        '''init parse'''
        self.args = args
        pass
    
    @staticmethod
    def check_dir(path):
        if not os.path.exists(path):
            os.makedirs(path, exist_ok= True)

    @staticmethod
    def get_state_dict(ckpt = None, url = None, model_dir = './checpoints'):
        '''raise 函数有待完善'''
        try:
            if ckpt != None:
                state_dict = torch.load(ckpt, map_location='cpu')
            
            elif url != None:
                try:
                    if model_dir != './checpoints':
                        state_dict = torch.hub.load_state_dict_from_url(url, model_dir= model_dir, map_location='cpu', check_hash= True)
                    else:
                        state_dict = torch.hub.load_state_dict_from_url(url, map_location='cpu', check_hash= True)
                except Exception as err:
                    state_dict = os.system(f'wget -P {model_dir} -c {url}')
        except Exception as err:
            print('please give a correct ckpt path or url')



        return state_dict
    
    @staticmethod
    def load_model1(model, state_dict):
        model_state = model.state_dict()
        parse_dict = {
            k:v for k, v in state_dict.items() if k in model_state.keys()
        }
        # model.state_dict().update(parse_dict)  #model.state_dict().update(parse_dict)并不能更新模型的参数
        model.load_state_dict(parse_dict)   #更新参数必须用load_state_dict
        

    @staticmethod
    def load_model2(model, state_dict):
        model_state = model.state_dict()     #model.state_dict() 返回的是每一层的名字以及对应的参数
        # for name in model.state_dict():      #但这个时候返回的name只是键
        #     model.state_dict()
        #     print(name)
        keys = model.state_dict().keys()   #这个时候返回的key也是键
        for key in keys:
            print(key)

        for k, v in state_dict.items():
            a = model.k
            model.state_dict().update(parse_dict)

if __name__ == '__main__':
    net = models.resnet50(pretrained= False)
    url = 'https://download.pytorch.org/models/resnet50-0676ba61.pth'
    state_dict = Model_Process.get_state_dict(url=url, model_dir = './xjm_checkpoints')
    Model_Process.load_model2(net, state_dict)

    print(0)

    print(1)


import cv2
import os
import numpy as np

from PIL import Image

'''
function one

First calculate the mean, then calculate the standard deviation

eg: mean = mean_std()
    std = mean_std(mean, m_or_s ='std')
    
root_path is the Parent directory of the Parent directory of picture
    eg: /home/xjm/xjm/xjm_pycharm/explain/custom_data/train/
    
'''

root_path = '/home/xjm/xjm/xjm_pycharm/shiyansheji/dataset/train/'

R_mean = 0
G_mean = 0
B_mean = 0

def mean_std( mean = [0,0,0], m_or_s = 'mean', root = None):

    '''


    :param mean: the mean of dataset which has been computed
    :param m_or_s: compute mean or std
    :return: mean or std
    '''

    R_img_mean = []
    G_img_mean = []
    B_img_mean = []

    R_mean = mean[0]
    G_mean = mean[1]
    B_mean = mean[2]

    R_img_std = []
    G_img_std = []
    B_img_std = []

    '''
    dir is class directory
    '''
    for dir in os.listdir(root_path):
        if dir == 'cat':
            print(1)
        sub_dir = os.path.join(root_path,dir)
        for img_name in os.listdir(sub_dir):
            img_path = os.path.join(sub_dir, img_name)

            if img_name != 'Thumbs.db':
                # img = cv2.imread(img_path)
                img = Image.open(img_path).convert('RGB')
                # img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
                img = np.asarray(img)
                img = img / 255
            else:
                continue

            if m_or_s == 'mean':
                R_img_mean.append(np.mean(img[:, :, 0]))
                G_img_mean.append(np.mean(img[:, :, 1]))
                B_img_mean.append(np.mean(img[:, :, 2]))
            else:
                assert m_or_s == 'std',  'only for mean or std'
                R_img_std.append(np.mean((img - R_mean) ** 2))
                G_img_std.append(np.mean((img - G_mean) ** 2))
                B_img_std.append(np.mean((img - B_mean) ** 2))
    if m_or_s == 'mean':
        R_mean = np.mean(R_img_mean)
        G_mean = np.mean(G_img_mean)
        B_mean = np.mean(B_img_mean)

        print('mean :',[R_mean, G_mean, B_mean])
        return [R_mean, G_mean, B_mean]
    elif  m_or_s == 'std':
        R_std = np.mean(R_img_std)
        G_std = np.mean(G_img_std)
        B_std = np.mean(B_img_std)

        print('std: ', [R_std, G_std, B_std])
        return [R_std, G_std, B_std]


'''
use the function
'''
mean = mean_std(root = root_path)
std = mean_std(mean, m_or_s = 'std', root = root_path)



'''
function two:only for mean
    
    The standard deviation cannot be calculated in this way because it is not an average
    
'''
def only_for_mean(root_path):
    mean = []
    # std = []
    R_mean_list = []
    G_mean_list = []
    B_mean_list = []

    # R_std_list = []
    # G_std_list = []
    # B_std_list = []
    '''
    dir is class directory
    '''
    for dir in os.listdir(root_path):
        sub_dir = os.path.join(root_path, dir)
        for img_name in os.listdir(sub_dir):
            img_path = os.path.join(sub_dir, img_name)

            if img_name != 'Thumbs.db':
                img = cv2.imread(img_path)
                img = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
                img = img / 255
            else:
                continue

            (R_img_mean, R_img_std) = cv2.meanStdDev(img[:, :, 0])
            (G_img_mean, G_img_std) = cv2.meanStdDev(img[:, :, 1])
            (B_img_mean, B_img_std) = cv2.meanStdDev(img[:, :, 2])

            R_mean_list.append(R_img_mean)
            G_mean_list.append(G_img_mean)
            B_mean_list.append(B_img_mean)

            # R_std_list.append(R_img_std)
            # G_std_list.append(G_img_std)
            # B_std_list.append(B_img_std)
    mean.append(np.mean(R_mean_list))
    mean.append(np.mean(G_mean_list))
    mean.append(np.mean(B_mean_list))
    '''
    The standard deviation cannot be calculated in this way because it is not an average
    '''
    # std.append(np.mean(R_std_list))
    # std.append(np.mean(G_std_list))
    # std.append(np.mean(B_std_list))

    print('mean:', mean)
    # print('std: ', std)
'''
use of only_for_mean
'''
# only_for_mean(root_path)


import cv2 as cv
import sys
import os
import matplotlib.pyplot as plt
from PIL import Image

if __name__ == '__main__':
    #读取图像并判断是否读取成功
    root_path = '/home/xjm/Code/R2GenCMN-main/Aug_image/d646_0015_again/'
    save_path = '/home/xjm/Code/R2GenCMN-main/Aug_image/d646_0015_again_all/'
    if not os.path.exists(save_path):
        os.makedirs(save_path,exist_ok=True)
    top_ax = [85,133]  #h,w
    bottom_ax = [200,190]
    Aug_para = 2
    Aug_location = 'left'
    for img_name in os.listdir(root_path):
        if 'no_limited' not in img_name:
            img_path = os.path.join(root_path, img_name)
            #cv2读出来的坐标是h,w,c(比如288，512，3) Image.open读出来是(w,h),比如512，288
            img = cv.imread(img_path)
            # img = cv.imread("/home/xjm/Code/R2GenCMN-main/WAIFA/vm512-motion-0020/0095--rvm.png")
            # img_= Image.open("/home/xjm/Code/R2GenCMN-main/WAIFA/vm512-motion-0020/0095--rvm.png")
            
            #需要放大的部分  这里是cv2读取的图片，所以，第二维度是宽，也就是x轴，第一维度是高，也就是y轴
            part = img[top_ax[0]:bottom_ax[0],top_ax[1]:bottom_ax[1]]  #h,w(y,x)
            #双线性插值法
            orig_heiht = bottom_ax[0] - top_ax[0]
            orig_width = bottom_ax[1] - top_ax[1]

            Aug_width = int(orig_width * Aug_para)
            Aug_height = int(orig_heiht * Aug_para)
            mask = cv.resize(part, (Aug_width, Aug_height), fx=0, fy=0, interpolation=cv.INTER_LINEAR) #cv.resize要用w,h(即x,y)
            if img is None is None:
                print('Failed to read picture')
                sys.exit()
                
            #放大后局部图的位置h,w
            if Aug_location == 'left':
                Aug_top = [top_ax[0] - int((orig_heiht * (Aug_para -1) )// 2) + 50 ,top_ax[1]- Aug_width -10] #h,w
                img[Aug_top[0]: Aug_top[0] + Aug_height, Aug_top[1]:Aug_top[1] + Aug_width]=mask
                cv.rectangle(img,(top_ax[1],top_ax[0]),(bottom_ax[1],bottom_ax[0]),(255,255,0),1)
                cv.rectangle(img,(Aug_top[1],Aug_top[0]),(Aug_top[1] + Aug_width,Aug_top[0] + Aug_height),(255,255,0),1)
                img = cv.line(img,(Aug_top[1]+ Aug_width, Aug_top[0]),(top_ax[1], top_ax[0]),(255,255,0))
                img = cv.line(img,(Aug_top[1]+ Aug_width,Aug_top[0] + Aug_height),(top_ax[1], bottom_ax[0]),(255,255,0))
            elif Aug_location == 'right':
                Aug_top = [top_ax[0] - int((orig_heiht * (Aug_para -1) )// 2) +100, bottom_ax[1] + 30]
                img[Aug_top[0]: Aug_top[0] + Aug_height, Aug_top[1]:Aug_top[1] + Aug_width]=mask
                cv.rectangle(img,(top_ax[1],top_ax[0]),(bottom_ax[1],bottom_ax[0]),(0,0,255),1)
                cv.rectangle(img,(Aug_top[1],Aug_top[0]),(Aug_top[1] + Aug_width,Aug_top[0] + Aug_height),(0,0,255),1)
                img = cv.line(img,(Aug_top[1], Aug_top[0]),(bottom_ax[1], top_ax[0]),(0,0,255))
                img = cv.line(img,(Aug_top[1], Aug_top[0] + Aug_height),(bottom_ax[1], bottom_ax[0]),(0,0,255))
                # img = cv.line(img,(Aug_top[1],Aug_top[2]),(100,50),(0,255,0))
                # img = cv.line(img,(350,400),(100,350),(0,255,0))
            elif Aug_location == 'bottom':
                Aug_top = [top_ax[0] - int((orig_heiht * (Aug_para -1) )// 2) +120, top_ax[1] + 10]  #h,w
                img[Aug_top[0]: Aug_top[0] + Aug_height, Aug_top[1]:Aug_top[1] + Aug_width]=mask
                cv.rectangle(img,(top_ax[1],top_ax[0]),(bottom_ax[1],bottom_ax[0]),(0,0,255),1) #w,h
                cv.rectangle(img,(Aug_top[1],Aug_top[0]),(Aug_top[1] + Aug_width,Aug_top[0] + Aug_height),(0,0,255),1)
                img = cv.line(img,(Aug_top[1], Aug_top[0]),(top_ax[1], bottom_ax[0]),(0,0,255)) #w,h
                img = cv.line(img,(Aug_top[1] + Aug_height, Aug_top[0]),(bottom_ax[1], bottom_ax[0]),(0,0,255))

            #画框并连线cv2的函数都是x,y的坐标
           

            #展示结果
            image_save_path = os.path.join(save_path, img_name)
            cv.imwrite(image_save_path,img)


import matplotlib.pyplot as plt
from PIL import Image
from collections import  OrderedDict
import os
import numpy
import cv2

mask_root_path = '/home/xjm/xjm/xjm_pycharm/PENet/results/PFNet/'
orige_img_path = '/home/xjm/xjm/xjm_pycharm/PENet/data/heart_old/test/'

sub_dir = ['HEART']

for dir in sub_dir:
    img_root_path = os.path.join(orige_img_path,'Imgs')
    mask_ori_path = os.path.join(orige_img_path,'mask')
    for img in os.listdir(img_root_path):
        img_path = os.path.join(img_root_path, img)

        mask_dir = img.split('.')[0] + '.png'
        result_name =  img.split('.')[0] + '_result.png'

        mask_pre_path = os.path.join(mask_root_path, dir, img)
        mask_ori_pic_path = os.path.join(mask_ori_path, img.replace('_img.png', '.png'))
        or_img = Image.open(img_path)
        print(or_img.size)
        or_img_data = numpy.asarray(or_img)

        or_img = Image.open(img_path).convert('RGB')
        mask_pre = Image.open(mask_pre_path).convert('RGB')
        mask_ori = Image.open(mask_ori_pic_path).convert('RGB')


        '''
        plt.subplots的使用，用完以后要记得plt.close
        另外plt.subplots(1,3, figsize = (7, 7))中的figsize中的数字回自动乘以100，所以一般取个位数即可
        plt.savefig可以保存整个fig
        '''
        fig, axes = plt.subplots(2,2, figsize = (7, 7))
        axes[0,0].set_title('original')
        axes[0,0].imshow(or_img)

        axes[0,1].set_title('original mask')
        axes[0,1].imshow(mask_ori)



        axes[1,0].set_title('prediction')
        axes[1,0].imshow(mask_pre)


        img_cv2= numpy.asarray(or_img)
        img_cv2 = img_cv2 / 255

        mask_cv2 = numpy.asarray(mask_pre)

        '''
        热力图必须先将原图片，和伪彩图片归一化，再相加，最后再归一化
        并且要注意，伪彩图本来是BGR模式的
        '''
        heatmap = cv2.applyColorMap(mask_cv2, cv2.COLORMAP_JET)
        heatmap = cv2.cvtColor(heatmap, cv2.COLOR_BGR2RGB)
        heatmap = heatmap / 255

        final_img = heatmap + img_cv2

        final_img = final_img/numpy.max(final_img)

        axes[1,1].set_title('result')
        axes[1,1].imshow(final_img)
        plt.show()
        plt.savefig('/home/xjm/xjm/xjm_pycharm/PENet/eval_show/heart200/' + result_name, bbox_inches='tight')
        plt.close(fig)



import random
import shutil
import os

img_root_path = '/home/data/zgdata/new_zg/devide_data/train/images/'
mask_root_path = '/home/data/zgdata/new_zg/devide_data/train/mask/'

test_img_path = '/home/data/zgdata/new_zg/devide_data/test/images/'
test_mask_path = '/home/data/zgdata/new_zg/devide_data/test/mask/'

test_percent = 0.2     #percent of train_pic

total_img = len(os.listdir(img_root_path))
test_num = int(test_percent * total_img)

'''
   move pic to train_dir
'''
for img_name in random.sample(os.listdir( img_root_path ), test_num):
    if img_name != 'Thumbs.db':
        mask_name = img_name.replace('jpg', 'png')
        shutil.move(os.path.join(img_root_path, img_name), test_img_path)

        # mask_name = img_name.replace('jpg','png')

        shutil.move(os.path.join(mask_root_path, mask_name), test_mask_path)
        print('move succeed')
    else:
        print('img name is not right')


# for class_dir in os.listdir(os.path.join(img_root_path,'train')):
#     test_img_path = os.path.join(img_root_path,'val', class_dir)
#     train_img_dir = os.path.join(img_root_path,'train',class_dir)
#
#     if not os.path.exists(test_img_path):
#         os.makedirs(test_img_path)
#
#     train_percent = 0.1  # percent of train_pic
#
#     total_img = len(os.listdir(train_img_dir))
#     train_num = int(train_percent * total_img)
#
#     for img_name in random.sample(os.listdir(train_img_dir), train_num):
#         if img_name != 'Thumbs.db':
#             shutil.move(os.path.join(train_img_dir, img_name), test_img_path)
#
#             # shutil.move(os.path.join(mask_root_path, mask_name), train_mask_path)
#             print('move succeed')
#         else:
#             print('img name is not right')
#
# for sub in os.listdir(img_root_path):
#     shutil.move(os.path.join(img_root_path, sub), train_img_path)
# for sub in os.listdir(mask_root_path):
#     shutil.move(os.path.join(mask_root_path, sub), train_mask_path)


# import requests
# import threading
# import re
# import queue
# import os
#
# def get_urls():
#     url = r'https://image.baidu.com/search/acjson?'
#     headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/101.0.4951.54 Safari/537.36 Edg/101.0.1210.39'}
#     pattern = '(http.*?jpg)'         #加括号，则会按照返回括号所匹配的结果，一个字符串多个括号，则会返回多个括号分别匹配到的结果：参考https://blog.csdn.net/qq_30534935/article/details/94589036
#     r = requests.get(url, headers = headers)
#
#     r.encoding = r.apparent_encoding  #修改内容的编码格式，否则可能是乱码
#
#     html = r.text     #r.text是网页内容，编码后内容; r.content返回的是二进制数据
#     img_urls = re.findall(pattern,html)
#
#     return img_urls
#
# a = get_urls()
# print(a)


'''

代码来自：https://zhuanlan.zhihu.com/p/367325899
'''

import requests
import os
import re


def get_images_from_baidu(keyword, page_num, save_dir):
    # UA 伪装：当前爬取信息伪装成浏览器
    # 将 User-Agent 封装到一个字典中
    # 【（网页右键 → 审查元素）或者 F12】 → 【Network】 → 【Ctrl+R】 → 左边选一项，右边在 【Response Hearders】 里查找
    header = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/78.0.3904.108 Safari/537.36'}
    # 请求的 url
    url = 'https://image.baidu.com/search/acjson?'
    # url = 'https://www.google.com.hk/search?q=Pelvic+X-ray&source=lnms&tbm=isch&sa=X&ved=2ahUKEwjF_NDO8d_9AhUOZt4KHahBBboQ_AUoAXoECAEQAw&biw=1707&bih=924&dpr=1.5'
    n = 0
    for pn in range(0, 30 * page_num, 30):
        # 请求参数
        param = {'tn': 'resultjson_com',
                 # 'logid': '7603311155072595725',
                 'ipn': 'rj',
                 'ct': 201326592,
                 'is': '',
                 'fp': 'result',
                 'queryWord': keyword,
                 'cl': 2,
                 'lm': -1,
                 'ie': 'utf-8',
                 'oe': 'utf-8',
                 'adpicid': '',
                 'st': -1,
                 'z': '',
                 'ic': '',
                 'hd': '',
                 'latest': '',
                 'copyright': '',
                 'word': keyword,
                 's': '',
                 'se': '',
                 'tab': '',
                 'width': '',
                 'height': '',
                 'face': 0,
                 'istype': 2,
                 'qc': '',
                 'nc': '1',
                 'fr': '',
                 'expermode': '',
                 'force': '',
                 'cg': '',    # 这个参数没公开，但是不可少
                 'pn': pn,    # 显示：30-60-90
                 'rn': '30',  # 每页显示 30 条
                 'gsm': '1e',
                 '1618827096642': ''
                 }
        request = requests.get(url=url, headers=header, params=param)
        if request.status_code == 200:
            print('Request success.')
        request.encoding = 'utf-8'
        # 正则方式提取图片链接
        html = request.text
        image_url_list = re.findall('"thumbURL":"(.*?)",', html, re.S)
        print(image_url_list)
        # # 换一种方式
        # request_dict = request.json()
        # info_list = request_dict['data']
        # # 看它的值最后多了一个，删除掉
        # info_list.pop()
        # image_url_list = []
        # for info in info_list:
        #     image_url_list.append(info['thumbURL'])

        if not os.path.exists(save_dir):
            os.makedirs(save_dir, exist_ok=True)

        for image_url in image_url_list:
            image_data = requests.get(url=image_url, headers=header).content
            with open(os.path.join(save_dir, f'{n:06d}.jpg'), 'wb') as fp:
                fp.write(image_data)
            n = n + 1


if __name__ == '__main__':
    keyword = 'Pelvic X-ray'
    save_dir = "/home/xjm/xjm/xjm_pycharm/gupen/gupen_google/"
    page_num = 100
    get_images_from_baidu(keyword, page_num, save_dir)
    print('Get images finished.')


import torch.cuda
from pynvml import *
 
 
def show_gpu(simlpe=True):
    # 初始化
    nvmlInit()
    # 获取GPU个数
    deviceCount = nvmlDeviceGetCount()
    total_memory = 0
    total_free = 0
    total_used = 0
    gpu_name = ""
    gpu_num = deviceCount
 
    for i in range(deviceCount):
        handle = nvmlDeviceGetHandleByIndex(i)
        info = nvmlDeviceGetMemoryInfo(handle)
        gpu_name = nvmlDeviceGetName(handle).decode('utf-8')
        # 查看型号、显存、温度、电源
        if not simlpe:
            print("[ GPU{}: {}".format(i, gpu_name), end="    ")
            print("总共显存: {}G".format((info.total//1048576)/1024), end="    ")
            print("空余显存: {}G".format((info.free//1048576)/1024), end="    ")
            print("已用显存: {}G".format((info.used//1048576)/1024), end="    ")
            print("显存占用率: {}%".format(info.used/info.total), end="    ")
            print("运行温度: {}摄氏度 ]".format(nvmlDeviceGetTemperature(handle,0)))
 
        total_memory += (info.total//1048576)/1024
        total_free += (info.free//1048576)/1024
        total_used += (info.used//1048576)/1024
 
    print("显卡名称：[{}]，显卡数量：[{}]，总共显存；[{}G]，空余显存：[{}G]，已用显存：[{}G]，显存占用率：[{}%]。".format(gpu_name, gpu_num, total_memory, total_free, total_used, (total_used/total_memory)))
 
    #关闭管理工具
    nvmlShutdown()
 
 
def use_gpu(used_percentage=0.75):
    '''
    不使用显存占用率高于used_percentage的gpu
    :param used_percentage:
    :return:
    '''
    nvmlInit()
    gpu_num = nvmlDeviceGetCount()
    out = ""
    for i in range(gpu_num):
        handle = nvmlDeviceGetHandleByIndex(i)
        info = nvmlDeviceGetMemoryInfo(handle)
        used_percentage_real = info.used / info.total
        if out == "":
            if used_percentage_real < used_percentage:
                out += str(i)
        else:
            if used_percentage_real < used_percentage:
                out += "," + str(i)
    nvmlShutdown()
    return out
 
show_gpu(False)
os.environ["CUDA_VISIBLE_DEVICES"] = use_gpu(0.5)  # 选择使用训练的GPU
 
 


import requests
import re
import os
import argparse
import urllib.parse

def get_image_urls(query, num_images):
    # 编码查询词为 URL 格式
    query = urllib.parse.quote(query)
    # 设置请求头信息
    headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36'}
    # 设置要请求的 URL
    url = "https://www.google.com/search?q="+query+"&source=lnms&tbm=isch"
    # 发送 GET 请求并获取结果
    response = requests.get(url, headers=headers).text
    # 从结果中提取图片链接
    image_urls = re.findall('"ou":"(.*?)"', response)[:num_images]
    return image_urls

def download_image(url, save_path):
    # 设置请求头信息
    headers = {'User-Agent': 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.36'}
    # 发送 GET 请求并保存图片
    response = requests.get(url, headers=headers)
    with open(save_path, 'wb') as f:
        f.write(response.content)

def main():
    # 设置参数解析器
    parser = argparse.ArgumentParser(description='Google 图片爬取')
    parser.add_argument('--query', type=str, default='cat', help='查询词')
    parser.add_argument('--num_images', type=int, default=10, help='要下载的图片数量')
    parser.add_argument('--save_directory', type=str, default='./images', help='保存目录')
    args = parser.parse_args()

    # 获取要下载的图片链接
    image_urls = get_image_urls(args.query, args.num_images)

    # 创建保存目录
    if not os.path.exists(args.save_directory):
        os.makedirs(args.save_directory)

    # 下载并保存图片
    for i, url in enumerate(image_urls):
        save_path = os.path.join(args.save_directory, f"{i}.jpg")
        download_image(url, save_path)
        print(f"{i+1}/{args.num_images} images downloaded from {url} to {save_path}")

if __name__ == '__main__':
    main()



import logging
from termcolor import colored

logger = logging.getLogger('xjm_test_log')
logger.setLevel(logging.DEBUG)

fh = logging.FileHandler('/home/xjm/xjm/xjm_pycharm/Attribute_Explainable/xjm.log')
fh.setLevel(logging.INFO)

ch = logging.StreamHandler()
ch.setLevel(logging.DEBUG)

formater = logging.Formatter(fmt = colored("[%(asctime)s]",'green') +'--'+ colored("{- %(name)s}",'yellow' ) + "- %(levelname)s - %(message)s",datefmt = '%Y-%m-%d %H:%M:%S')

fh.setFormatter(formater)
ch.setFormatter(formater)

logger.addHandler(fh)
logger.addHandler(ch)

logger.debug("debug message")
logger.info("info message")
logger.warning("warn message")
logger.error("error message")
logger.critical("critical message")


print('ok')